@@ -1,5 +1,5 @@
 package WebAPI::DBIC;
-$WebAPI::DBIC::VERSION = '0.001004';
+$WebAPI::DBIC::VERSION = '0.001006';
 use strict; # keep our kwalitee up!
 use warnings;
 1;
@@ -16,7 +16,7 @@ WebAPI::DBIC
 
 =head1 VERSION
 
-version 0.001004
+version 0.001006
 
 =head1 DESCRIPTION
 
@@ -31,10 +31,13 @@ WebAPI::DBIC features include:
 
 * Supports safe robust multi-related-record CRUD transactions
 
-* Built on the strong foundations of L<Web::Machine>, L<Path::Router> and L<Plack>
+* Built on the strong foundations of L<Web::Machine> and L<Plack>, with
+L<Path::Router> as the router. (We aim to support other routers soon.)
 
 * Built as fine-grained roles for maximum reusability and extensibility
 
+* The resource roles can be added to your existing application
+
 * A built-in copy of the generic HAL API browser application
 
 * An example .psgi file that gives you an instant web service for any DBIx::Class schema
@@ -97,13 +100,12 @@ DBIx::Class schema. This is what makes the API discoverable and browseable.
 
 =head1 NAME
 
-WebAPI::DBIC - A composable RESTful JSON+HAL API to DBIx::Class schemas using roles, Web::Machine and Path::Router
+WebAPI::DBIC - A composable RESTful JSON+HAL API to DBIx::Class schemas using roles and Web::Machine
 
 =head1 STATUS
 
 The WebAPI::DBIC code has been in production use since early 2013, however it's
-only recently been open sourced (July 2014) so it's still lacking in
-documentation, tests etc.
+only recently been open sourced (July 2014) so it's still lacking in documentation.
 
 It's also likely to undergo a period of refactoring now there are more
 developers contributing and the code is being applied to more domains.
@@ -190,32 +192,49 @@ have their values JSON decoded, so they can be arbitrary data structures.
 
 =head2 Resource Classes
 
-To make building typical applications easier, WebAPI::DBIC provides three
+To make building typical applications easier, WebAPI::DBIC provides four
 pre-defined resource classes:
 
-L<WebAPI::DBIC::Resource::GenericItemDBIC> for resources represented by an
-individual DBIx::Class row.
+L<WebAPI::DBIC::Resource::GenericCore> is a base class that consumes all the
+general-purpose resource roles.
 
-L<WebAPI::DBIC::Resource::GenericSetDBIC> for resources represented by a
-DBIx::Class result set.
+L<WebAPI::DBIC::Resource::GenericItem> subclasses GenericCore and consumes
+extra roles for resources represented by an individual DBIx::Class row.
 
-L<WebAPI::DBIC::Resource::GenericItemInvoke> for resources that represent a
-specific method call on an item resource.
+L<WebAPI::DBIC::Resource::GenericSet> subclasses GenericCore and consumes extra
+roles for resources represented by a DBIx::Class result set.
+
+L<WebAPI::DBIC::Resource::GenericItemInvoke> subclasses GenericCore and
+consumes extra roles for resources that represent a specific method call on an
+item resource.
 
 These classes are I<very> simple because all the work is done by the various
 roles they consume. For example, here's the entire code for
-L<WebAPI::DBIC::Resource::GenericItemDBIC>:
+L<WebAPI::DBIC::Resource::GenericCore>:
 
-    package WebAPI::DBIC::Resource::GenericItemDBIC;
+    package WebAPI::DBIC::Resource::GenericCore;
     use Moo;
-    extends 'WebAPI::DBIC::Resource::Base'; # is just Web::Machine::Resource
+    extends 'WebAPI::DBIC::Resource::Base';
     with    'WebAPI::DBIC::Role::JsonEncoder',
             'WebAPI::DBIC::Role::JsonParams',
+            'WebAPI::DBIC::Resource::Role::Router',
+            'WebAPI::DBIC::Resource::Role::Identity',
+            'WebAPI::DBIC::Resource::Role::Relationship',
             'WebAPI::DBIC::Resource::Role::DBIC',
+            'WebAPI::DBIC::Resource::Role::DBICException',
             'WebAPI::DBIC::Resource::Role::DBICAuth',
             'WebAPI::DBIC::Resource::Role::DBICParams',
-            'WebAPI::DBIC::Resource::Role::Item',
-            'WebAPI::DBIC::Resource::Role::ItemWritable',
+            ;
+    1;
+
+and L<WebAPI::DBIC::Resource::GenericItem>:
+
+    package WebAPI::DBIC::Resource::GenericSet;
+    use Moo;
+    extends 'WebAPI::DBIC::Resource::GenericCore';
+    with    'WebAPI::DBIC::Resource::Role::SetRender',
+            'WebAPI::DBIC::Resource::Role::Set',
+            'WebAPI::DBIC::Resource::Role::SetWritable',
             ;
     1;
 
@@ -225,11 +244,18 @@ A few other classes are provided:
 
 L<WebAPI::DBIC::Util.pm> provides a few general utilities.
 
-L<WebAPI::DBIC::Machine.pm> a subclass of L<Web::Machine>.
-
 L<WebAPI::DBIC::WebApp> - this is the main app class and is most likely to
 change in the near future so isn't documented yet.
 
+=head1 LIMITATIONS AND OUTSTANDING DESIGN ISSUES
+
+The only supported router is Path::Router at the moment.
+
+See also https://metacpan.org/pod/distribution/WebAPI-DBIC/NOTES.pod
+and https://github.com/timbunce/WebAPI-DBIC/issues
+
+If there's anything you specifically need, just ask!
+
 =head1 HOW TO GET HELP
 
 =over
@@ -337,7 +363,9 @@ would include
 
 The "relation" links describe the relationships this resource has with other resources.
 
-TBD Currently only 1-1 relationships (e.g., belongs_to) are included. Also see L</prefetch>.
+Currently only 1-1 relationships (e.g., belongs_to) are and simple 1-N
+(has_many) relationships are supported and get C<_links>.
+Also see L</prefetch>.
 
 =head2 GET Item - Optional Parameters
 
