@@ -1,9 +1,20 @@
 package WebAPI::DBIC::Resource::Base;
-$WebAPI::DBIC::Resource::Base::VERSION = '0.001004';
+$WebAPI::DBIC::Resource::Base::VERSION = '0.001006';
 
 use Moo;
 extends 'Web::Machine::Resource';
 
+
+has http_auth_type => (
+   is => 'ro',
+);
+
+has throwable => (
+    is => 'rw',
+    required => 1,
+);
+
+
 1;
 
 __END__
@@ -18,7 +29,7 @@ WebAPI::DBIC::Resource::Base
 
 =head1 VERSION
 
-version 0.001004
+version 0.001006
 
 =head1 DESCRIPTION
 
