@@ -1,16 +1,11 @@
 package WebAPI::DBIC::Resource::GenericItemInvoke;
-$WebAPI::DBIC::Resource::GenericItemInvoke::VERSION = '0.001004';
+$WebAPI::DBIC::Resource::GenericItemInvoke::VERSION = '0.001006';
+
 use Moo;
 use namespace::clean;
 
-extends 'WebAPI::DBIC::Resource::Base';
-with    'WebAPI::DBIC::Role::JsonEncoder',
-        'WebAPI::DBIC::Role::JsonParams',
-        'WebAPI::DBIC::Resource::Role::DBIC',
-        'WebAPI::DBIC::Resource::Role::DBICException',
-        'WebAPI::DBIC::Resource::Role::DBICAuth',
-        'WebAPI::DBIC::Resource::Role::DBICParams',
-        'WebAPI::DBIC::Resource::Role::Item',
+extends 'WebAPI::DBIC::Resource::GenericCore';
+with    'WebAPI::DBIC::Resource::Role::Item',
         'WebAPI::DBIC::Resource::Role::ItemInvoke',
         ;
 
@@ -28,7 +23,11 @@ WebAPI::DBIC::Resource::GenericItemInvoke
 
 =head1 VERSION
 
-version 0.001004
+version 0.001006
+
+=head1 NAME
+
+WebAPI::DBIC::Resource::GenericItemInvoke - a set of roles to implement a resource for making method calls on a DBIC item
 
 =head1 AUTHOR
 
