@@ -1,16 +1,19 @@
 package WebAPI::DBIC::Resource::Role::Item;
-$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.001004';
+$WebAPI::DBIC::Resource::Role::Item::VERSION = '0.001006';
+
 use Moo::Role;
 
 
 requires 'render_item_as_plain_hash';
 requires 'render_item_as_hal_hash';
+requires 'id_unique_constraint_name';
 requires 'encode_json';
 requires 'set';
 
 
-has id => (
+has id => (         # array of 1 or more key values from url path
    is => 'ro',
+   #isa => array ref
    required => 1,
 );
 
@@ -22,7 +25,7 @@ has item => (
 
 sub _build_item {
     my $self = shift;
-    return $self->set->find($self->id);
+    return $self->set->find( @{ $self->id }, { key => $self->id_unique_constraint_name } );
 }
 
 
@@ -53,7 +56,18 @@ WebAPI::DBIC::Resource::Role::Item
 
 =head1 VERSION
 
-version 0.001004
+version 0.001006
+
+=head1 DESCRIPTION
+
+Handles GET and HEAD requests for requests representing individual resources,
+e.g. a single row of a database table.
+
+Supports the C<application/hal+json> and C<application/json> content types.
+
+=head1 NAME
+
+WebAPI::DBIC::Resource::Role::Item - methods related to handling requests for item resources
 
 =head1 AUTHOR
 
